/*
 * misc.h
 */

/*
 * Created 1993 by Juha.Virtanen@HUT.Fi
 */

#ifndef _MISC_H
#define _MISC_H

/* typedef int (* outfuntype)(int); */		/* Now in termcap.h */

extern void err (const char *fmt, ...);

extern void cat (char *file);

extern void outc (int c);

#endif /* ! _MISC_H */
